=============
Import Linter
=============

.. image:: https://img.shields.io/pypi/v/import-linter.svg
    :target: https://pypi.org/project/import-linter

.. image:: https://img.shields.io/pypi/pyversions/import-linter.svg
    :alt: Python versions
    :target: https://pypi.org/project/import-linter/

.. image:: https://api.travis-ci.org/seddonym/import-linter.svg?branch=master
    :target: https://travis-ci.org/seddonym/import-linter


Import Linter allows you to define and enforce rules for the internal and external imports within your Python project.

* Free software: BSD license

**Warning:** This software is currently being developed; it is not ready to use.
